@@ -1,5 +1,5 @@
     Mac OS X            	   2                 TxMt                          ATTR
-         "                     "  com.macromates.caret {
+         !                     !  com.macromates.caret {
     column = 0;
-    line = 29;
+    line = 4;
 }
\ No newline at end of file
